Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/asyncio_simpletest.py
    :caption: examples/asyncio_simpletest.py
    :linenos:

Displayio Button Example
------------------------

Illustrates how to use Display_Buttons and blinking vectorio.Circles with asyncio

.. literalinclude:: ../examples/asyncio_displayio_button.py
    :caption: examples/asyncio_displayio_button.py
    :linenos:
